==> flink-streaming-java_2.11-1.10.0-sources.jar: org/apache/flink/streaming/runtime/io/AbstractDataOutput.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.flink.streaming.runtime.io;

import org.apache.flink.annotation.Internal;
import org.apache.flink.streaming.runtime.streamstatus.StreamStatus;
import org.apache.flink.streaming.runtime.streamstatus.StreamStatusMaintainer;

import static org.apache.flink.util.Preconditions.checkNotNull;

/**
 * Base class for all data outputs. It implements the unified way of emitting stream status
 * for both network and source outputs.
 *
 * @param <T> The output type
 */
@Internal
public abstract class AbstractDataOutput<T> implements PushingAsyncDataInput.DataOutput<T> {

	/** The maintainer toggles the current stream status. */
	protected final StreamStatusMaintainer streamStatusMaintainer;

	protected final Object lock;

	public AbstractDataOutput(StreamStatusMaintainer streamStatusMaintainer, Object lock) {
		this.streamStatusMaintainer = checkNotNull(streamStatusMaintainer);
		this.lock = checkNotNull(lock);
	}

	@Override
	public void emitStreamStatus(StreamStatus streamStatus) {
		synchronized (lock) {
			streamStatusMaintainer.toggleStreamStatus(streamStatus);
		}
	}
}

==> flink-streaming-java_2.12-1.11.4-sources.jar: org/apache/flink/streaming/runtime/io/AbstractDataOutput.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.flink.streaming.runtime.io;

import org.apache.flink.annotation.Internal;
import org.apache.flink.streaming.runtime.streamstatus.StreamStatus;
import org.apache.flink.streaming.runtime.streamstatus.StreamStatusMaintainer;

import static org.apache.flink.util.Preconditions.checkNotNull;

/**
 * Base class for all data outputs. It implements the unified way of emitting stream status for both
 * network and source outputs.
 *
 * @param <T> The output type
 */
@Internal
public abstract class AbstractDataOutput<T> implements PushingAsyncDataInput.DataOutput<T> {

    /** The maintainer toggles the current stream status. */
    protected final StreamStatusMaintainer streamStatusMaintainer;

    public AbstractDataOutput(StreamStatusMaintainer streamStatusMaintainer) {
        this.streamStatusMaintainer = checkNotNull(streamStatusMaintainer);
    }

    @Override
    public void emitStreamStatus(StreamStatus streamStatus) {
        streamStatusMaintainer.toggleStreamStatus(streamStatus);
    }
}
